@@ -16,8 +16,7 @@
 #define TABRMD_ENTROPY_SRC_DEFAULT "/dev/urandom"
 #define TABRMD_SESSIONS_MAX_DEFAULT 4
 #define TABRMD_SESSIONS_MAX 64
-#define TABRMD_TCTI_FILENAME_DEFAULT "libtss2-tcti-device.so.0"
-#define TABRMD_TCTI_CONF_DEFAULT NULL
+#define TABRMD_TCTI_CONF_DEFAULT "device:/dev/tpm0"
 #define TABRMD_TRANSIENT_MAX_DEFAULT 27
 #define TABRMD_TRANSIENT_MAX 100
 
