@@ -6,6 +6,7 @@
 #include <glib.h>
 #include <inttypes.h>
 #include <stdlib.h>
+#include <sysexits.h>
 #include <unistd.h>
 #include <tss2/tss2_tpm2_types.h>
 
@@ -34,7 +35,7 @@ main (int argc, char *argv[])
 {
     gmain_data_t gmain_data = { .options = TABRMD_OPTIONS_INIT_DEFAULT };
     GThread *init_thread;
-    gint init_ret;
+    gint ret;
 
     g_info ("tabrmd startup");
     if (!parse_opts (argc, argv, &gmain_data.options)) {
@@ -42,7 +43,8 @@ main (int argc, char *argv[])
     }
     if (geteuid() == 0 && ! gmain_data.options.allow_root) {
         g_print ("Refusing to run as root. Pass --allow-root if you know what you are doing.\n");
-        return 1;
+        ret = 1;
+        goto out;
     }
 
     g_mutex_init (&gmain_data.init_mutex);
@@ -58,7 +60,11 @@ main (int argc, char *argv[])
     g_info ("entering g_main_loop");
     g_main_loop_run (gmain_data.loop);
     g_info ("g_main_loop_run done, cleaning up");
-    init_ret = GPOINTER_TO_INT (g_thread_join (init_thread));
+    ret = GPOINTER_TO_INT (g_thread_join (init_thread));
+    if (ret == 0 && gmain_data.ipc_disconnected) {
+        ret = EX_IOERR;
+    }
+out:
     gmain_data_cleanup (&gmain_data);
-    return init_ret;
+    return ret;
 }
